@@ -2,7 +2,6 @@
 #define _CALLBACK_REGISTRY_H_
 
 #include <Rcpp.h>
-#include <queue>
 #include <atomic>
 #include <functional>
 #include <memory>
@@ -39,8 +38,6 @@ public:
 
   virtual void invoke() const = 0;
 
-  void invoke_wrapped() const;
-
   virtual Rcpp::RObject rRepresentation() const = 0;
 
   Timestamp when;
@@ -57,15 +54,12 @@ public:
   StdFunctionCallback(Timestamp when, std::function<void (void)> func);
 
   void invoke() const {
-#ifdef RCPP_USING_UNWIND_PROTECT // See https://github.com/r-lib/later/issues/191
+    // See https://github.com/r-lib/later/issues/191 and https://github.com/r-lib/later/pull/241
     Rcpp::unwindProtect([this]() {
       BEGIN_RCPP
       func();
       END_RCPP
     });
-#else
-    func();
-#endif
   }
 
   Rcpp::RObject rRepresentation() const;
